@@ -1,6 +1,6 @@
 ## Pushforward
 
-struct FastDifferentiationOneArgPushforwardPrep{SIG,Y,E1,E1!} <: DI.PushforwardPrep{SIG}
+struct FastDifferentiationOneArgPushforwardPrep{SIG, Y, E1, E1!} <: DI.PushforwardPrep{SIG}
     _sig::Val{SIG}
     y_prototype::Y
     jvp_exe::E1
@@ -8,13 +8,13 @@ struct FastDifferentiationOneArgPushforwardPrep{SIG,Y,E1,E1!} <: DI.PushforwardP
 end
 
 function DI.prepare_pushforward_nokwarg(
-    strict::Val,
-    f,
-    backend::AutoFastDifferentiation,
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Context,C};
-) where {C}
+        strict::Val,
+        f,
+        backend::AutoFastDifferentiation,
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Context, C}
+    ) where {C}
     _sig = DI.signature(f, backend, x, tx, contexts...; strict)
     y_prototype = f(x, map(DI.unwrap, contexts)...)
     x_var = variablize(x, :x)
@@ -25,22 +25,22 @@ function DI.prepare_pushforward_nokwarg(
     y_vec_var = myvec(y_var)
     jv_vec_var, v_vec_var = jacobian_times_v(y_vec_var, x_vec_var)
     jvp_exe = make_function(
-        jv_vec_var, x_vec_var, v_vec_var, context_vec_vars...; in_place=false
+        jv_vec_var, x_vec_var, v_vec_var, context_vec_vars...; in_place = false
     )
     jvp_exe! = make_function(
-        jv_vec_var, x_vec_var, v_vec_var, context_vec_vars...; in_place=true
+        jv_vec_var, x_vec_var, v_vec_var, context_vec_vars...; in_place = true
     )
     return FastDifferentiationOneArgPushforwardPrep(_sig, y_prototype, jvp_exe, jvp_exe!)
 end
 
 function DI.pushforward(
-    f,
-    prep::FastDifferentiationOneArgPushforwardPrep,
-    backend::AutoFastDifferentiation,
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        prep::FastDifferentiationOneArgPushforwardPrep,
+        backend::AutoFastDifferentiation,
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     ty = map(tx) do dx
         result = prep.jvp_exe(myvec(x), myvec(dx), map(myvec_unwrap, contexts)...)
@@ -54,14 +54,14 @@ function DI.pushforward(
 end
 
 function DI.pushforward!(
-    f,
-    ty::NTuple,
-    prep::FastDifferentiationOneArgPushforwardPrep,
-    backend::AutoFastDifferentiation,
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        ty::NTuple,
+        prep::FastDifferentiationOneArgPushforwardPrep,
+        backend::AutoFastDifferentiation,
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     for b in eachindex(tx, ty)
         dx, dy = tx[b], ty[b]
@@ -71,48 +71,48 @@ function DI.pushforward!(
 end
 
 function DI.value_and_pushforward(
-    f,
-    prep::FastDifferentiationOneArgPushforwardPrep,
-    backend::AutoFastDifferentiation,
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        prep::FastDifferentiationOneArgPushforwardPrep,
+        backend::AutoFastDifferentiation,
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     return f(x, map(DI.unwrap, contexts)...),
-    DI.pushforward(f, prep, backend, x, tx, contexts...)
+        DI.pushforward(f, prep, backend, x, tx, contexts...)
 end
 
 function DI.value_and_pushforward!(
-    f,
-    ty::NTuple,
-    prep::FastDifferentiationOneArgPushforwardPrep,
-    backend::AutoFastDifferentiation,
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        ty::NTuple,
+        prep::FastDifferentiationOneArgPushforwardPrep,
+        backend::AutoFastDifferentiation,
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     return f(x, map(DI.unwrap, contexts)...),
-    DI.pushforward!(f, ty, prep, backend, x, tx, contexts...)
+        DI.pushforward!(f, ty, prep, backend, x, tx, contexts...)
 end
 
 ## Pullback
 
-struct FastDifferentiationOneArgPullbackPrep{SIG,E1,E1!} <: DI.PullbackPrep{SIG}
+struct FastDifferentiationOneArgPullbackPrep{SIG, E1, E1!} <: DI.PullbackPrep{SIG}
     _sig::Val{SIG}
     vjp_exe::E1
     vjp_exe!::E1!
 end
 
 function DI.prepare_pullback_nokwarg(
-    strict::Val,
-    f,
-    backend::AutoFastDifferentiation,
-    x,
-    ty::NTuple,
-    contexts::Vararg{DI.Context,C};
-) where {C}
+        strict::Val,
+        f,
+        backend::AutoFastDifferentiation,
+        x,
+        ty::NTuple,
+        contexts::Vararg{DI.Context, C}
+    ) where {C}
     _sig = DI.signature(f, backend, x, ty, contexts...; strict)
     x_var = variablize(x, :x)
     context_vars = variablize(contexts)
@@ -123,22 +123,22 @@ function DI.prepare_pullback_nokwarg(
     y_vec_var = myvec(y_var)
     vj_vec_var, v_vec_var = jacobian_transpose_v(y_vec_var, x_vec_var)
     vjp_exe = make_function(
-        vj_vec_var, x_vec_var, v_vec_var, context_vec_vars...; in_place=false
+        vj_vec_var, x_vec_var, v_vec_var, context_vec_vars...; in_place = false
     )
     vjp_exe! = make_function(
-        vj_vec_var, x_vec_var, v_vec_var, context_vec_vars...; in_place=true
+        vj_vec_var, x_vec_var, v_vec_var, context_vec_vars...; in_place = true
     )
     return FastDifferentiationOneArgPullbackPrep(_sig, vjp_exe, vjp_exe!)
 end
 
 function DI.pullback(
-    f,
-    prep::FastDifferentiationOneArgPullbackPrep,
-    backend::AutoFastDifferentiation,
-    x,
-    ty::NTuple,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        prep::FastDifferentiationOneArgPullbackPrep,
+        backend::AutoFastDifferentiation,
+        x,
+        ty::NTuple,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, ty, contexts...)
     tx = map(ty) do dy
         result = prep.vjp_exe(myvec(x), myvec(dy), map(myvec_unwrap, contexts)...)
@@ -152,14 +152,14 @@ function DI.pullback(
 end
 
 function DI.pullback!(
-    f,
-    tx::NTuple,
-    prep::FastDifferentiationOneArgPullbackPrep,
-    backend::AutoFastDifferentiation,
-    x,
-    ty::NTuple,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        tx::NTuple,
+        prep::FastDifferentiationOneArgPullbackPrep,
+        backend::AutoFastDifferentiation,
+        x,
+        ty::NTuple,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, ty, contexts...)
     for b in eachindex(tx, ty)
         dx, dy = tx[b], ty[b]
@@ -169,35 +169,35 @@ function DI.pullback!(
 end
 
 function DI.value_and_pullback(
-    f,
-    prep::FastDifferentiationOneArgPullbackPrep,
-    backend::AutoFastDifferentiation,
-    x,
-    ty::NTuple,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        prep::FastDifferentiationOneArgPullbackPrep,
+        backend::AutoFastDifferentiation,
+        x,
+        ty::NTuple,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, ty, contexts...)
     return f(x, map(DI.unwrap, contexts)...),
-    DI.pullback(f, prep, backend, x, ty, contexts...)
+        DI.pullback(f, prep, backend, x, ty, contexts...)
 end
 
 function DI.value_and_pullback!(
-    f,
-    tx::NTuple,
-    prep::FastDifferentiationOneArgPullbackPrep,
-    backend::AutoFastDifferentiation,
-    x,
-    ty::NTuple,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        tx::NTuple,
+        prep::FastDifferentiationOneArgPullbackPrep,
+        backend::AutoFastDifferentiation,
+        x,
+        ty::NTuple,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, ty, contexts...)
     return f(x, map(DI.unwrap, contexts)...),
-    DI.pullback!(f, tx, prep, backend, x, ty, contexts...)
+        DI.pullback!(f, tx, prep, backend, x, ty, contexts...)
 end
 
 ## Derivative
 
-struct FastDifferentiationOneArgDerivativePrep{SIG,Y,E1,E1!} <: DI.DerivativePrep{SIG}
+struct FastDifferentiationOneArgDerivativePrep{SIG, Y, E1, E1!} <: DI.DerivativePrep{SIG}
     _sig::Val{SIG}
     y_prototype::Y
     der_exe::E1
@@ -205,8 +205,8 @@ struct FastDifferentiationOneArgDerivativePrep{SIG,Y,E1,E1!} <: DI.DerivativePre
 end
 
 function DI.prepare_derivative_nokwarg(
-    strict::Val, f, backend::AutoFastDifferentiation, x, contexts::Vararg{DI.Context,C};
-) where {C}
+        strict::Val, f, backend::AutoFastDifferentiation, x, contexts::Vararg{DI.Context, C}
+    ) where {C}
     _sig = DI.signature(f, backend, x, contexts...; strict)
     y_prototype = f(x, map(DI.unwrap, contexts)...)
     x_var = variablize(x, :x)
@@ -217,18 +217,18 @@ function DI.prepare_derivative_nokwarg(
     context_vec_vars = map(myvec, context_vars)
     y_vec_var = myvec(y_var)
     der_vec_var = derivative(y_vec_var, x_var)
-    der_exe = make_function(der_vec_var, x_vec_var, context_vec_vars...; in_place=false)
-    der_exe! = make_function(der_vec_var, x_vec_var, context_vec_vars...; in_place=true)
+    der_exe = make_function(der_vec_var, x_vec_var, context_vec_vars...; in_place = false)
+    der_exe! = make_function(der_vec_var, x_vec_var, context_vec_vars...; in_place = true)
     return FastDifferentiationOneArgDerivativePrep(_sig, y_prototype, der_exe, der_exe!)
 end
 
 function DI.derivative(
-    f,
-    prep::FastDifferentiationOneArgDerivativePrep,
-    backend::AutoFastDifferentiation,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        prep::FastDifferentiationOneArgDerivativePrep,
+        backend::AutoFastDifferentiation,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     result = prep.der_exe(myvec(x), map(myvec_unwrap, contexts)...)
     if prep.y_prototype isa Number
@@ -239,54 +239,54 @@ function DI.derivative(
 end
 
 function DI.derivative!(
-    f,
-    der,
-    prep::FastDifferentiationOneArgDerivativePrep,
-    backend::AutoFastDifferentiation,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        der,
+        prep::FastDifferentiationOneArgDerivativePrep,
+        backend::AutoFastDifferentiation,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     prep.der_exe!(myvec(der), myvec(x), map(myvec_unwrap, contexts)...)
     return der
 end
 
 function DI.value_and_derivative(
-    f,
-    prep::FastDifferentiationOneArgDerivativePrep,
-    backend::AutoFastDifferentiation,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        prep::FastDifferentiationOneArgDerivativePrep,
+        backend::AutoFastDifferentiation,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     return f(x, map(DI.unwrap, contexts)...),
-    DI.derivative(f, prep, backend, x, contexts...)
+        DI.derivative(f, prep, backend, x, contexts...)
 end
 
 function DI.value_and_derivative!(
-    f,
-    der,
-    prep::FastDifferentiationOneArgDerivativePrep,
-    backend::AutoFastDifferentiation,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        der,
+        prep::FastDifferentiationOneArgDerivativePrep,
+        backend::AutoFastDifferentiation,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     return f(x, map(DI.unwrap, contexts)...),
-    DI.derivative!(f, der, prep, backend, x, contexts...)
+        DI.derivative!(f, der, prep, backend, x, contexts...)
 end
 
 ## Gradient
 
-struct FastDifferentiationOneArgGradientPrep{SIG,E1,E1!} <: DI.GradientPrep{SIG}
+struct FastDifferentiationOneArgGradientPrep{SIG, E1, E1!} <: DI.GradientPrep{SIG}
     _sig::Val{SIG}
     jac_exe::E1
     jac_exe!::E1!
 end
 
 function DI.prepare_gradient_nokwarg(
-    strict::Val, f, backend::AutoFastDifferentiation, x, contexts::Vararg{DI.Context,C};
-) where {C}
+        strict::Val, f, backend::AutoFastDifferentiation, x, contexts::Vararg{DI.Context, C}
+    ) where {C}
     _sig = DI.signature(f, backend, x, contexts...; strict)
     x_var = variablize(x, :x)
     context_vars = variablize(contexts)
@@ -296,18 +296,18 @@ function DI.prepare_gradient_nokwarg(
     context_vec_vars = map(myvec, context_vars)
     y_vec_var = myvec(y_var)
     jac_var = jacobian(y_vec_var, x_vec_var)
-    jac_exe = make_function(jac_var, x_vec_var, context_vec_vars...; in_place=false)
-    jac_exe! = make_function(jac_var, x_vec_var, context_vec_vars...; in_place=true)
+    jac_exe = make_function(jac_var, x_vec_var, context_vec_vars...; in_place = false)
+    jac_exe! = make_function(jac_var, x_vec_var, context_vec_vars...; in_place = true)
     return FastDifferentiationOneArgGradientPrep(_sig, jac_exe, jac_exe!)
 end
 
 function DI.gradient(
-    f,
-    prep::FastDifferentiationOneArgGradientPrep,
-    backend::AutoFastDifferentiation,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        prep::FastDifferentiationOneArgGradientPrep,
+        backend::AutoFastDifferentiation,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     jac = prep.jac_exe(myvec(x), map(myvec_unwrap, contexts)...)
     grad_vec = @view jac[1, :]
@@ -315,45 +315,45 @@ function DI.gradient(
 end
 
 function DI.gradient!(
-    f,
-    grad,
-    prep::FastDifferentiationOneArgGradientPrep,
-    backend::AutoFastDifferentiation,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        grad,
+        prep::FastDifferentiationOneArgGradientPrep,
+        backend::AutoFastDifferentiation,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     prep.jac_exe!(reshape(grad, 1, length(grad)), myvec(x), map(myvec_unwrap, contexts)...)
     return grad
 end
 
 function DI.value_and_gradient(
-    f,
-    prep::FastDifferentiationOneArgGradientPrep,
-    backend::AutoFastDifferentiation,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        prep::FastDifferentiationOneArgGradientPrep,
+        backend::AutoFastDifferentiation,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     return f(x, map(DI.unwrap, contexts)...), DI.gradient(f, prep, backend, x, contexts...)
 end
 
 function DI.value_and_gradient!(
-    f,
-    grad,
-    prep::FastDifferentiationOneArgGradientPrep,
-    backend::AutoFastDifferentiation,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        grad,
+        prep::FastDifferentiationOneArgGradientPrep,
+        backend::AutoFastDifferentiation,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     return f(x, map(DI.unwrap, contexts)...),
-    DI.gradient!(f, grad, prep, backend, x, contexts...)
+        DI.gradient!(f, grad, prep, backend, x, contexts...)
 end
 
 ## Jacobian
 
-struct FastDifferentiationOneArgJacobianPrep{SIG,Y,P,E1,E1!} <: DI.SparseJacobianPrep{SIG}
+struct FastDifferentiationOneArgJacobianPrep{SIG, Y, P, E1, E1!} <: DI.SparseJacobianPrep{SIG}
     _sig::Val{SIG}
     y_prototype::Y
     sparsity::P
@@ -362,12 +362,12 @@ struct FastDifferentiationOneArgJacobianPrep{SIG,Y,P,E1,E1!} <: DI.SparseJacobia
 end
 
 function DI.prepare_jacobian_nokwarg(
-    strict::Val,
-    f,
-    backend::Union{AutoFastDifferentiation,AutoSparse{<:AutoFastDifferentiation}},
-    x,
-    contexts::Vararg{DI.Context,C};
-) where {C}
+        strict::Val,
+        f,
+        backend::Union{AutoFastDifferentiation, AutoSparse{<:AutoFastDifferentiation}},
+        x,
+        contexts::Vararg{DI.Context, C}
+    ) where {C}
     _sig = DI.signature(f, backend, x, contexts...; strict)
     y_prototype = f(x, map(DI.unwrap, contexts)...)
     x_var = variablize(x, :x)
@@ -384,65 +384,65 @@ function DI.prepare_jacobian_nokwarg(
         jac_var = jacobian(y_vec_var, x_vec_var)
         sparsity = nothing
     end
-    jac_exe = make_function(jac_var, x_vec_var, context_vec_vars...; in_place=false)
-    jac_exe! = make_function(jac_var, x_vec_var, context_vec_vars...; in_place=true)
+    jac_exe = make_function(jac_var, x_vec_var, context_vec_vars...; in_place = false)
+    jac_exe! = make_function(jac_var, x_vec_var, context_vec_vars...; in_place = true)
     return FastDifferentiationOneArgJacobianPrep(
         _sig, y_prototype, sparsity, jac_exe, jac_exe!
     )
 end
 
 function DI.jacobian(
-    f,
-    prep::FastDifferentiationOneArgJacobianPrep,
-    backend::Union{AutoFastDifferentiation,AutoSparse{<:AutoFastDifferentiation}},
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        prep::FastDifferentiationOneArgJacobianPrep,
+        backend::Union{AutoFastDifferentiation, AutoSparse{<:AutoFastDifferentiation}},
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     return prep.jac_exe(myvec(x), map(myvec_unwrap, contexts)...)
 end
 
 function DI.jacobian!(
-    f,
-    jac,
-    prep::FastDifferentiationOneArgJacobianPrep,
-    backend::Union{AutoFastDifferentiation,AutoSparse{<:AutoFastDifferentiation}},
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        jac,
+        prep::FastDifferentiationOneArgJacobianPrep,
+        backend::Union{AutoFastDifferentiation, AutoSparse{<:AutoFastDifferentiation}},
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     prep.jac_exe!(jac, myvec(x), map(myvec_unwrap, contexts)...)
     return jac
 end
 
 function DI.value_and_jacobian(
-    f,
-    prep::FastDifferentiationOneArgJacobianPrep,
-    backend::Union{AutoFastDifferentiation,AutoSparse{<:AutoFastDifferentiation}},
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        prep::FastDifferentiationOneArgJacobianPrep,
+        backend::Union{AutoFastDifferentiation, AutoSparse{<:AutoFastDifferentiation}},
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     return f(x, map(DI.unwrap, contexts)...), DI.jacobian(f, prep, backend, x, contexts...)
 end
 
 function DI.value_and_jacobian!(
-    f,
-    jac,
-    prep::FastDifferentiationOneArgJacobianPrep,
-    backend::Union{AutoFastDifferentiation,AutoSparse{<:AutoFastDifferentiation}},
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        jac,
+        prep::FastDifferentiationOneArgJacobianPrep,
+        backend::Union{AutoFastDifferentiation, AutoSparse{<:AutoFastDifferentiation}},
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     return f(x, map(DI.unwrap, contexts)...),
-    DI.jacobian!(f, jac, prep, backend, x, contexts...)
+        DI.jacobian!(f, jac, prep, backend, x, contexts...)
 end
 
 ## Second derivative
 
-struct FastDifferentiationAllocatingSecondDerivativePrep{SIG,Y,D,E2,E2!} <:
-       DI.SecondDerivativePrep{SIG}
+struct FastDifferentiationAllocatingSecondDerivativePrep{SIG, Y, D, E2, E2!} <:
+    DI.SecondDerivativePrep{SIG}
     _sig::Val{SIG}
     y_prototype::Y
     derivative_prep::D
@@ -451,8 +451,8 @@ struct FastDifferentiationAllocatingSecondDerivativePrep{SIG,Y,D,E2,E2!} <:
 end
 
 function DI.prepare_second_derivative_nokwarg(
-    strict::Val, f, backend::AutoFastDifferentiation, x, contexts::Vararg{DI.Context,C};
-) where {C}
+        strict::Val, f, backend::AutoFastDifferentiation, x, contexts::Vararg{DI.Context, C}
+    ) where {C}
     _sig = DI.signature(f, backend, x, contexts...; strict)
     y_prototype = f(x, map(DI.unwrap, contexts)...)
     x_var = variablize(x, :x)
@@ -464,8 +464,8 @@ function DI.prepare_second_derivative_nokwarg(
     y_vec_var = myvec(y_var)
 
     der2_vec_var = derivative(y_vec_var, x_var, x_var)
-    der2_exe = make_function(der2_vec_var, x_vec_var, context_vec_vars...; in_place=false)
-    der2_exe! = make_function(der2_vec_var, x_vec_var, context_vec_vars...; in_place=true)
+    der2_exe = make_function(der2_vec_var, x_vec_var, context_vec_vars...; in_place = false)
+    der2_exe! = make_function(der2_vec_var, x_vec_var, context_vec_vars...; in_place = true)
 
     derivative_prep = DI.prepare_derivative_nokwarg(strict, f, backend, x, contexts...)
     return FastDifferentiationAllocatingSecondDerivativePrep(
@@ -474,12 +474,12 @@ function DI.prepare_second_derivative_nokwarg(
 end
 
 function DI.second_derivative(
-    f,
-    prep::FastDifferentiationAllocatingSecondDerivativePrep,
-    backend::AutoFastDifferentiation,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        prep::FastDifferentiationAllocatingSecondDerivativePrep,
+        backend::AutoFastDifferentiation,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     result = prep.der2_exe(myvec(x), map(myvec_unwrap, contexts)...)
     if prep.y_prototype isa Number
@@ -490,25 +490,25 @@ function DI.second_derivative(
 end
 
 function DI.second_derivative!(
-    f,
-    der2,
-    prep::FastDifferentiationAllocatingSecondDerivativePrep,
-    backend::AutoFastDifferentiation,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        der2,
+        prep::FastDifferentiationAllocatingSecondDerivativePrep,
+        backend::AutoFastDifferentiation,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     prep.der2_exe!(myvec(der2), myvec(x), map(myvec_unwrap, contexts)...)
     return der2
 end
 
 function DI.value_derivative_and_second_derivative(
-    f,
-    prep::FastDifferentiationAllocatingSecondDerivativePrep,
-    backend::AutoFastDifferentiation,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        prep::FastDifferentiationAllocatingSecondDerivativePrep,
+        backend::AutoFastDifferentiation,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     y, der = DI.value_and_derivative(f, prep.derivative_prep, backend, x, contexts...)
     der2 = DI.second_derivative(f, prep, backend, x, contexts...)
@@ -516,14 +516,14 @@ function DI.value_derivative_and_second_derivative(
 end
 
 function DI.value_derivative_and_second_derivative!(
-    f,
-    der,
-    der2,
-    prep::FastDifferentiationAllocatingSecondDerivativePrep,
-    backend::AutoFastDifferentiation,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        der,
+        der2,
+        prep::FastDifferentiationAllocatingSecondDerivativePrep,
+        backend::AutoFastDifferentiation,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     y, _ = DI.value_and_derivative!(f, der, prep.derivative_prep, backend, x, contexts...)
     DI.second_derivative!(f, der2, prep, backend, x, contexts...)
@@ -532,7 +532,7 @@ end
 
 ## HVP
 
-struct FastDifferentiationHVPPrep{SIG,E2,E2!,E1} <: DI.HVPPrep{SIG}
+struct FastDifferentiationHVPPrep{SIG, E2, E2!, E1} <: DI.HVPPrep{SIG}
     sig::Val{SIG}
     hvp_exe::E2
     hvp_exe!::E2!
@@ -540,13 +540,13 @@ struct FastDifferentiationHVPPrep{SIG,E2,E2!,E1} <: DI.HVPPrep{SIG}
 end
 
 function DI.prepare_hvp_nokwarg(
-    strict::Val,
-    f,
-    backend::AutoFastDifferentiation,
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Context,C};
-) where {C}
+        strict::Val,
+        f,
+        backend::AutoFastDifferentiation,
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Context, C}
+    ) where {C}
     _sig = DI.signature(f, backend, x, tx, contexts...; strict)
     x_var = variablize(x, :x)
     context_vars = variablize(contexts)
@@ -556,10 +556,10 @@ function DI.prepare_hvp_nokwarg(
     context_vec_vars = map(myvec, context_vars)
     hv_vec_var, v_vec_var = hessian_times_v(y_var, x_vec_var)
     hvp_exe = make_function(
-        hv_vec_var, x_vec_var, v_vec_var, context_vec_vars...; in_place=false
+        hv_vec_var, x_vec_var, v_vec_var, context_vec_vars...; in_place = false
     )
     hvp_exe! = make_function(
-        hv_vec_var, x_vec_var, v_vec_var, context_vec_vars...; in_place=true
+        hv_vec_var, x_vec_var, v_vec_var, context_vec_vars...; in_place = true
     )
 
     gradient_prep = DI.prepare_gradient_nokwarg(strict, f, backend, x, contexts...)
@@ -567,13 +567,13 @@ function DI.prepare_hvp_nokwarg(
 end
 
 function DI.hvp(
-    f,
-    prep::FastDifferentiationHVPPrep,
-    backend::AutoFastDifferentiation,
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        prep::FastDifferentiationHVPPrep,
+        backend::AutoFastDifferentiation,
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     tg = map(tx) do dx
         dg_vec = prep.hvp_exe(myvec(x), myvec(dx), map(myvec_unwrap, contexts)...)
@@ -583,14 +583,14 @@ function DI.hvp(
 end
 
 function DI.hvp!(
-    f,
-    tg::NTuple,
-    prep::FastDifferentiationHVPPrep,
-    backend::AutoFastDifferentiation,
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        tg::NTuple,
+        prep::FastDifferentiationHVPPrep,
+        backend::AutoFastDifferentiation,
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     for b in eachindex(tx, tg)
         dx, dg = tx[b], tg[b]
@@ -600,13 +600,13 @@ function DI.hvp!(
 end
 
 function DI.gradient_and_hvp(
-    f,
-    prep::FastDifferentiationHVPPrep,
-    backend::AutoFastDifferentiation,
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        prep::FastDifferentiationHVPPrep,
+        backend::AutoFastDifferentiation,
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     tg = DI.hvp(f, prep, backend, x, tx, contexts...)
     grad = DI.gradient(f, prep.gradient_prep, backend, x, contexts...)
@@ -614,15 +614,15 @@ function DI.gradient_and_hvp(
 end
 
 function DI.gradient_and_hvp!(
-    f,
-    grad,
-    tg::NTuple,
-    prep::FastDifferentiationHVPPrep,
-    backend::AutoFastDifferentiation,
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        grad,
+        tg::NTuple,
+        prep::FastDifferentiationHVPPrep,
+        backend::AutoFastDifferentiation,
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     DI.hvp!(f, tg, prep, backend, x, tx, contexts...)
     DI.gradient!(f, grad, prep.gradient_prep, backend, x, contexts...)
@@ -631,7 +631,7 @@ end
 
 ## Hessian
 
-struct FastDifferentiationHessianPrep{SIG,G,P,E2,E2!} <: DI.SparseHessianPrep{SIG}
+struct FastDifferentiationHessianPrep{SIG, G, P, E2, E2!} <: DI.SparseHessianPrep{SIG}
     _sig::Val{SIG}
     gradient_prep::G
     sparsity::P
@@ -640,12 +640,12 @@ struct FastDifferentiationHessianPrep{SIG,G,P,E2,E2!} <: DI.SparseHessianPrep{SI
 end
 
 function DI.prepare_hessian_nokwarg(
-    strict::Val,
-    f,
-    backend::Union{AutoFastDifferentiation,AutoSparse{<:AutoFastDifferentiation}},
-    x,
-    contexts::Vararg{DI.Context,C};
-) where {C}
+        strict::Val,
+        f,
+        backend::Union{AutoFastDifferentiation, AutoSparse{<:AutoFastDifferentiation}},
+        x,
+        contexts::Vararg{DI.Context, C}
+    ) where {C}
     _sig = DI.signature(f, backend, x, contexts...; strict)
     x_var = variablize(x, :x)
     context_vars = variablize(contexts)
@@ -661,8 +661,8 @@ function DI.prepare_hessian_nokwarg(
         hess_var = hessian(y_var, x_vec_var)
         sparsity = nothing
     end
-    hess_exe = make_function(hess_var, x_vec_var, context_vec_vars...; in_place=false)
-    hess_exe! = make_function(hess_var, x_vec_var, context_vec_vars...; in_place=true)
+    hess_exe = make_function(hess_var, x_vec_var, context_vec_vars...; in_place = false)
+    hess_exe! = make_function(hess_var, x_vec_var, context_vec_vars...; in_place = true)
 
     gradient_prep = DI.prepare_gradient_nokwarg(
         strict, f, dense_ad(backend), x, contexts...
@@ -673,36 +673,36 @@ function DI.prepare_hessian_nokwarg(
 end
 
 function DI.hessian(
-    f,
-    prep::FastDifferentiationHessianPrep,
-    backend::Union{AutoFastDifferentiation,AutoSparse{<:AutoFastDifferentiation}},
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        prep::FastDifferentiationHessianPrep,
+        backend::Union{AutoFastDifferentiation, AutoSparse{<:AutoFastDifferentiation}},
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     return prep.hess_exe(myvec(x), map(myvec_unwrap, contexts)...)
 end
 
 function DI.hessian!(
-    f,
-    hess,
-    prep::FastDifferentiationHessianPrep,
-    backend::Union{AutoFastDifferentiation,AutoSparse{<:AutoFastDifferentiation}},
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        hess,
+        prep::FastDifferentiationHessianPrep,
+        backend::Union{AutoFastDifferentiation, AutoSparse{<:AutoFastDifferentiation}},
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     prep.hess_exe!(hess, myvec(x), map(myvec_unwrap, contexts)...)
     return hess
 end
 
 function DI.value_gradient_and_hessian(
-    f,
-    prep::FastDifferentiationHessianPrep,
-    backend::Union{AutoFastDifferentiation,AutoSparse{<:AutoFastDifferentiation}},
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        prep::FastDifferentiationHessianPrep,
+        backend::Union{AutoFastDifferentiation, AutoSparse{<:AutoFastDifferentiation}},
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     y, grad = DI.value_and_gradient(
         f, prep.gradient_prep, dense_ad(backend), x, contexts...
@@ -712,14 +712,14 @@ function DI.value_gradient_and_hessian(
 end
 
 function DI.value_gradient_and_hessian!(
-    f,
-    grad,
-    hess,
-    prep::FastDifferentiationHessianPrep,
-    backend::Union{AutoFastDifferentiation,AutoSparse{<:AutoFastDifferentiation}},
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {C}
+        f,
+        grad,
+        hess,
+        prep::FastDifferentiationHessianPrep,
+        backend::Union{AutoFastDifferentiation, AutoSparse{<:AutoFastDifferentiation}},
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     y, _ = DI.value_and_gradient!(
         f, grad, prep.gradient_prep, dense_ad(backend), x, contexts...
